==> mule-transport-xmpp-1.3-rc5-sources.jar: org/mule/providers/xmpp/XmppEndpointBuilder.java <==
/*
 * $Id: XmppEndpointBuilder.java 3167 2006-09-22 15:47:04 +0000 (Fri, 22 Sep 2006) holger $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the MuleSource MPL
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.providers.xmpp;

import org.mule.config.i18n.Message;
import org.mule.impl.endpoint.UserInfoEndpointBuilder;
import org.mule.umo.endpoint.MalformedEndpointException;

import java.net.URI;
import java.util.Properties;

/**
 * Does the same as the UserINfoEndpointBuilder but also ensures that a path is
 * set on the uri.  The path is used as either the groupChat name or the recipient name
 * of a one on one chat.
 *
 * @author <a href="mailto:ross.mason@symphonysoft.com">Ross Mason</a>
 * @version $Revision: 3167 $
 */
public class XmppEndpointBuilder extends UserInfoEndpointBuilder
{
    protected void setEndpoint(URI uri, Properties props) throws MalformedEndpointException
    {
        if(uri.getPath().length()==0) {
            throw new MalformedEndpointException(new Message("xmpp", 1), uri.toString());
        }
        if(props.getProperty(XmppConnector.XMPP_GROUP_CHAT, "false").equalsIgnoreCase("true")) {
            if(props.getProperty(XmppConnector.XMPP_NICKNAME, null)==null) {
                throw new MalformedEndpointException(new Message("xmpp", 2), uri.toString());
            }
        }
        super.setEndpoint(uri, props);
    }
}

==> mule-transport-xmpp-1.3.2-sources.jar: org/mule/providers/xmpp/XmppEndpointBuilder.java <==
/*
 * $Id: XmppEndpointBuilder.java 3798 2006-11-04 04:07:14Z aperepel $
 * --------------------------------------------------------------------------------------
 * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
 *
 * The software in this package is published under the terms of the MuleSource MPL
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */

package org.mule.providers.xmpp;

import org.mule.config.i18n.Message;
import org.mule.impl.endpoint.UserInfoEndpointBuilder;
import org.mule.umo.endpoint.MalformedEndpointException;

import java.net.URI;
import java.util.Properties;

/**
 * Does the same as the UserINfoEndpointBuilder but also ensures that a path is set
 * on the uri. The path is used as either the groupChat name or the recipient name of
 * a one on one chat.
 * 
 * @author <a href="mailto:ross.mason@symphonysoft.com">Ross Mason</a>
 * @version $Revision: 3798 $
 */
public class XmppEndpointBuilder extends UserInfoEndpointBuilder
{
    protected void setEndpoint(URI uri, Properties props) throws MalformedEndpointException
    {
        if (uri.getPath().length() == 0)
        {
            throw new MalformedEndpointException(new Message("xmpp", 1), uri.toString());
        }
        if (props.getProperty(XmppConnector.XMPP_GROUP_CHAT, "false").equalsIgnoreCase("true"))
        {
            if (props.getProperty(XmppConnector.XMPP_NICKNAME, null) == null)
            {
                throw new MalformedEndpointException(new Message("xmpp", 2), uri.toString());
            }
        }
        super.setEndpoint(uri, props);
    }
}
